@@ -12,20 +12,15 @@ extern "C" {
 /**
  * Greatest version of API described by this header.
  *
- * Generally, later versions of the API are backwards-compatible
- * with prior versions. In order to maintain compatibility with the maximum
- * number of library versions, the user should pass the lowest required
- * API version wherever possible to relevant API functions.
- *
  * A number of structure definitions described in this header begin with
- * a member indicating the API version used by the caller. Whenver such
+ * a member indicating the API version used by the caller. Whenever such
  * a structure is a parameter to a function, the version field should be set
  * to the API version corresponding to its layout to ensure that the library
  * does not access memory beyond the end of the structure.
  */
 #define ZIMG_MAKE_API_VERSION(x, y) (((x) << 8) | (y))
 #define ZIMG_API_VERSION_MAJOR 2
-#define ZIMG_API_VERSION_MINOR 0
+#define ZIMG_API_VERSION_MINOR 1
 #define ZIMG_API_VERSION ZIMG_MAKE_API_VERSION(ZIMG_API_VERSION_MAJOR, ZIMG_API_VERSION_MINOR)
 
 /**
@@ -91,9 +86,9 @@ typedef enum zimg_error_code_e {
 	 * While all API errors result from illegal parameters, this category
 	 * indicates a locally determinable error, such as an out of range enum.
 	 */
-	ZIMG_ERROR_ILLEGAL_ARGUMENT  = (2 << 10),
-	ZIMG_ERROR_ENUM_OUT_OF_RANGE = ZIMG_ERROR_ILLEGAL_ARGUMENT + 1, /**< Value not in enumeration. */
-	ZIMG_ERROR_ZERO_IMAGE_SIZE   = ZIMG_ERROR_ILLEGAL_ARGUMENT + 2, /**< Image width or height is zero. */
+	ZIMG_ERROR_ILLEGAL_ARGUMENT   = (2 << 10),
+	ZIMG_ERROR_ENUM_OUT_OF_RANGE  = ZIMG_ERROR_ILLEGAL_ARGUMENT + 1, /**< Value not in enumeration. */
+	ZIMG_ERROR_INVALID_IMAGE_SIZE = ZIMG_ERROR_ILLEGAL_ARGUMENT + 2, /**< Image size or region is not well-formed. */
 
 	/**
 	 * A requested conversion was not supported by the library.
@@ -418,7 +413,7 @@ void zimg_filter_graph_free(zimg_filter_graph *ptr);
 zimg_error_code_e zimg_filter_graph_get_tmp_size(const zimg_filter_graph *ptr, size_t *out);
 
 /**
- * Query the maximum number of lines required in the input buffer.
+ * Query the minimum number of lines required in the input buffer.
  *
  * When reading an image through a user-defined callback function, the loaded
  * image data is stored in a buffer of sufficient size for the granularity of
@@ -432,7 +427,7 @@ zimg_error_code_e zimg_filter_graph_get_tmp_size(const zimg_filter_graph *ptr, s
 zimg_error_code_e zimg_filter_graph_get_input_buffering(const zimg_filter_graph *ptr, unsigned *out);
 
 /**
- * Query the maximum number of lines required in the output buffer.
+ * Query the minimum number of lines required in the output buffer.
  *
  * @pre out != 0
  * @param ptr graph handle
@@ -483,6 +478,14 @@ typedef struct zimg_image_format {
 
 	zimg_field_parity_e field_parity;                         /**< Field parity (default ZIMG_FIELD_PROGRESSIVE). */
 	zimg_chroma_location_e chroma_location;                   /**< Chroma location (default ZIMG_CHROMA_LEFT). */
+
+	/** Active image subrectangle. Since API 2.1 */
+	struct {
+		double left;   /**< Subpixel index of left image boundary (default NAN, treated as 0). */
+		double top;    /**< Subpixel index of top image boundary (default NAN, treated as 0). */
+		double width;  /**< Subpixel width, counting from {@link left} (default NAN, same as image width). */
+		double height; /**< Subpixel height, counting from {@link top} (default NAN, same as image height). */
+	} active_region;
 } zimg_image_format;
 
 /**
@@ -514,7 +517,6 @@ typedef struct zimg_graph_builder_params {
 	double filter_param_b_uv;                  /**< @see filter_param_a */
 
 	zimg_dither_type_e dither_type;            /**< Dithering method (default ZIMG_DITHER_NONE). */
-
 	zimg_cpu_type_e cpu_type;                  /**< Target CPU architecture (default ZIMG_CPU_AUTO). */
 } zimg_graph_builder_params;
 
